@@ -13,6 +13,7 @@ class ebb(Variable):
         eligible = spm_unit("is_ebb_eligible", period)
         broadband_cost = spm_unit("broadband_cost", period)
         tribal = spm_unit.household("is_on_tribal_land", period)
-        max_amount = parameters(period).fcc.ebb.amount[tribal] * 12
+        amounts = parameters(period).fcc.ebb.amount
+        max_amount = where(tribal, amounts.tribal, amounts.standard) * 12
         amount_if_eligible = min_(max_amount, broadband_cost)
         return where(eligible, amount_if_eligible, 0)
